@@ -17,7 +17,7 @@ class NetstatHelper : public QObject
 {
     Q_OBJECT
 public:
-    NetstatHelper();
+    using QObject::QObject;
     QString errorString() const;
     bool hasError() const;
 
@@ -42,7 +42,6 @@ private:
     QString m_errorString;
     bool m_hasError = false;
     QProcess *m_executableProcess = nullptr;
-    QTimer *m_processKillerTimer = nullptr;
     bool m_hasTimeoutError = false;
 };
 
